module.exports = defineTest({
	description: 'Creates a facade if necessary for strict entry signatures',
	options: {
		preserveEntrySignatures: 'strict'
	}
});
